@@ -33,25 +33,9 @@ from .usecases import (
     AdvancedCustomerServiceUseCase,
     LicensePlateUseCase,
     ColorDetectionUseCase,
-    PotholeSegmentationUseCase,
     PPEComplianceUseCase,
     VehicleMonitoringUseCase,
-    MaskDetectionUseCase,
-    CarDamageDetectionUseCase,
-    FireSmokeUseCase,
-    FlareAnalysisUseCase,
-    ParkingSpaceUseCase,
-    FaceEmotionUseCase,
-    UnderwaterPlasticUseCase,
-    PedestrianDetectionUseCase,
-
-    AgeDetectionUseCase,
-    WeldDefectUseCase,
-
-    AgeDetectionUseCase,
-    PriceTagUseCase
-
-
+    FireSmokeUseCase
 )
 
 logger = logging.getLogger(__name__)
@@ -108,7 +92,7 @@ class PostProcessor:
         registry.register_use_case("sales", "advanced_customer_service", AdvancedCustomerServiceUseCase)
         
         # Register license plate detection use case
-        registry.register_use_case("license_plate", "license_plate_detection", LicensePlateUseCase)
+        registry.register_use_case("vehicle", "license_plate_detection", LicensePlateUseCase)
         
         # Register color detection use case
         registry.register_use_case("visual_appearance", "color_detection", ColorDetectionUseCase)
@@ -118,20 +102,9 @@ class PostProcessor:
         
         # Register PPE compliance use case
         registry.register_use_case("ppe", "ppe_compliance_detection", PPEComplianceUseCase)
-        registry.register_use_case("infrastructure", "pothole_segmentation", PotholeSegmentationUseCase)
-        registry.register_use_case("car_damage", "car_damage_detection", CarDamageDetectionUseCase)
 
         registry.register_use_case("traffic", "vehicle_monitoring", VehicleMonitoringUseCase)
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
-        registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
-        registry.register_use_case("general", "face_emotion", FaceEmotionUseCase)
-        registry.register_use_case("parking_space", "parking_space_detection", ParkingSpaceUseCase)
-        registry.register_use_case("environmental", "underwater_pollution_detection", UnderwaterPlasticUseCase)
-        registry.register_use_case("pedestrian", "pedestrian_detection", PedestrianDetectionUseCase)  
-        registry.register_use_case("security", "age_detection", AgeDetectionUseCase)
-        registry.register_use_case("weld", "weld_defect_detection", WeldDefectUseCase)
-        registry.register_use_case("price_tag", "price_tag_detection", PriceTagUseCase)
-        registry.register_use_case("mask_detection", "mask_detection", MaskDetectionUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -226,8 +199,6 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, input_bytes, context, stream_info)
             elif isinstance(use_case, VehicleMonitoringUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-            elif isinstance(use_case, FlareAnalysisUseCase):
-                result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
             elif isinstance(use_case,LicensePlateUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
             else:
