@@ -572,7 +572,6 @@ class Projects:
         dataset_name,
         file_path,
         dataset_type,
-        project_type="detection",
         input_type="image",
         bucket_alias="",
         compute_alias="",
@@ -615,7 +614,6 @@ class Projects:
         >>> print(f"Dataset created: {dataset}")
         """
         return self._create_dataset(
-            project_type=project_type,
             dataset_name=dataset_name,
             dataset_type=dataset_type,
             input_type=input_type,
@@ -633,7 +631,6 @@ class Projects:
         source_url,
         cloud_provider,
         dataset_type,
-        project_type="detection",
         input_type="image",
         bucket_alias="",
         compute_alias="",
@@ -679,7 +676,6 @@ class Projects:
         >>> print(f"Dataset created: {dataset}")
         """
         return self._create_dataset(
-            project_type,
             dataset_name=dataset_name,
             dataset_type=dataset_type,
             input_type=input_type,
@@ -2131,4 +2127,4 @@ class Projects:
                     "percentageWork": int(percentage_work),
                 }
             )
-        return validated_users
\ No newline at end of file
+        return validated_users
